==> dl.php?src=linea21_1_8.zip: linea21/languages/en/lang_news.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['news']['section'] = "news";

/*	nommage des modules
 *  	*/
$lang['news']['name']='news';
$lang['news']['confirm_add'] = "News successfully added\n";
$lang['news']['confirm_mod'] = "News successfully updated\n";
$lang['news']['confirm_sup'] ="News successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['news']['add']= 'Add a new '.$lang['news']['name'];
$lang['news']['mod']= 'Edit '.$lang['news']['name'];
$lang['news']['sup']= 'Delete '.$lang['news']['name'];
$lang['news']['det']= ucfirst($lang['news']['name']). ' details';
$lang['news']['list']= 'View '.$lang['news']['name'];


/*	nommage rubrique add / mod /det
 *  	*/
$lang['news']['add_title']='Enter data about the new '.$lang['news']['name'];
$lang['news']['mod_title']='Edit data about '.$lang['news']['name'];
$lang['news']['recap_commment']='no comment';


/*	check integrité des données
 *  	*/
$lang['news']['no_scale']='Scale is required';
$lang['news']['no_theme']='Theme is required';
$lang['news']['no_title']='Title is required';
$lang['news']['no_body']='Body is required';
$lang['news']['no_header']='Header is required';



/*	nommage élément rubrique
 *  	*/
$lang['news']['title']='title';
$lang['news']['header']= 'header';
$lang['news']['body']= 'body';
$lang['news']['theme']='associated theme';
$lang['news']['scale']='associated scale';
$lang['news']['statut']='status';
$lang['news']['author']='author';



/*	nommage quickbox
 *  	*/
$lang['news']['qb_titleadd']=' latest additions';
$lang['news']['qb_titlemod']=' latest modifications';
$lang['news']['qb_titlesup']=' latest deletions';
$lang['news']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['news']['nb_total']='news in database.';
$lang['news']['statut_filter']='Display by status';
$lang['news']['all']='Display list';
$lang['news']['noresult']='There is no news with this criteria ';


/*	public
 *  	*/

$lang['news']['name2']='news';
$lang['news']['next_news']='next news ';
$lang['news']['prev_news']='previous news ';
/*	rubrique d'aide
 *  	*/
$lang['news']['help_add1']='To add a news, please insert the required informations in the form above';
$lang['news']['help_add2']='After submitting the form, check your data in the summary';
$lang['news']['help_add3']='After checking summary, click the \'review settings\' button to make changes';


$lang['news']['help_list1']='Click on news title to display more informations';
$lang['news']['help_list2']='Delete news by clicking on the delete icon linked in';
$lang['news']['help_list3']='Edit news by clicking on the edit icon linked in';
$lang['news']['help_list4']='Filter by status to display news for a given status';
$lang['news']['help_list5']='Click \'add a news\' button for adding news';
$lang['news']['help_list6']="To perform search on news only, just click the 'search' link";


$lang['news']['help_mod1']='To edit a news, please insert the required informations in the form above';
$lang['news']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['news']['help_mod3']='Once the summary displayed, click the \'review settings\' button if you need to make new changes';


$lang['news']['help_det1']='Delete news by clicking on the delete icon linked in';
$lang['news']['help_det2']='Edit news by clicking on the edit icon linked in';

$lang['news']['help_sup1']='Click cancel to abort deletion';
?>

==> dl.php?src=linea21_2_3_0.zip: linea21/languages/en/lang_news.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['news']['section'] = "news";

/*	nommage des modules
 *  	*/
$lang['news']['name']='news';
$lang['news']['confirm_add'] = "News successfully added\n";
$lang['news']['confirm_mod'] = "News successfully updated\n";
$lang['news']['confirm_sup'] ="News successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['news']['add']= 'Add a new '.$lang['news']['name'];
$lang['news']['mod']= 'Edit '.$lang['news']['name'];
$lang['news']['sup']= 'Delete '.$lang['news']['name'];
$lang['news']['det']= ucfirst($lang['news']['name']). ' details';
$lang['news']['list']= 'View '.$lang['news']['name'];


/*	nommage rubrique add / mod /det
 *  	*/
$lang['news']['add_title']='Enter data about the new '.$lang['news']['name'];
$lang['news']['mod_title']='Edit data about '.$lang['news']['name'];
$lang['news']['recap_commment']='no comment';


/*	check integrité des données
 *  	*/
$lang['news']['no_scale']='Scale is required';
$lang['news']['no_level']='Level is required';
$lang['news']['no_title']='Title is required';
$lang['news']['no_body']='Body is required';
$lang['news']['no_header']='Header is required';



/*	nommage élément rubrique
 *  	*/
$lang['news']['title']='title';
$lang['news']['header']= 'header';
$lang['news']['body']= 'body';
$lang['news']['level']='associated level';
$lang['news']['scale']='associated scale';
$lang['news']['statut']='status';
$lang['news']['author']='author';



/*	nommage quickbox
 *  	*/
$lang['news']['qb_titleadd']=' latest additions';
$lang['news']['qb_titlemod']=' latest modifications';
$lang['news']['qb_titlesup']=' latest deletions';
$lang['news']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['news']['nb_total']='news in database.';
$lang['news']['statut_filter']='Display by status';
$lang['news']['all']='Display list';
$lang['news']['noresult']='There is no news with this criteria ';


/*	public
 *  	*/

$lang['news']['name2']='news';
$lang['news']['next_news']='next news ';
$lang['news']['prev_news']='previous news ';
/*	rubrique d'aide
 *  	*/
$lang['news']['help_add1']='To add a news, please insert the required informations in the form above';
$lang['news']['help_add2']='After submitting the form, check your data in the summary';
$lang['news']['help_add3']='After checking summary, click the \'review settings\' button to make changes';


$lang['news']['help_list1']='Click on news title to display more informations';
$lang['news']['help_list2']='Delete news by clicking on the delete icon linked in';
$lang['news']['help_list3']='Edit news by clicking on the edit icon linked in';
$lang['news']['help_list4']='Filter by status to display news for a given status';
$lang['news']['help_list5']='Click \'add a news\' button for adding news';
$lang['news']['help_list6']="To perform search on news only, just click the 'search' link";


$lang['news']['help_mod1']='To edit a news, please insert the required informations in the form above';
$lang['news']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['news']['help_mod3']='Once the summary displayed, click the \'review settings\' button if you need to make new changes';


$lang['news']['help_det1']='Delete news by clicking on the delete icon linked in';
$lang['news']['help_det2']='Edit news by clicking on the edit icon linked in';

$lang['news']['help_sup1']='Click cancel to abort deletion';
?>
